@@ -1,4 +1,6 @@
+"""Engines without parallelization."""
 from typing import List
+
 from tqdm import tqdm
 
 from .base import Engine
@@ -7,8 +9,9 @@ from .task import Task
 
 class SingleCoreEngine(Engine):
     """
-    Dummy engine for sequential execution on one core. Note that the
-    objective itself may be multithreaded.
+    Dummy engine for sequential execution on one core.
+
+    Note that the objective itself may be multithreaded.
     """
 
     def __init__(self):
