@@ -6,7 +6,7 @@ Optimize
 Multistart optimization with support for various optimizers.
 """
 
-from .ess import ESSOptimizer
+from .ess import CESSOptimizer, ESSOptimizer, SacessOptimizer
 from .load import (
     fill_result_from_history,
     optimization_result_from_history,
