@@ -1,28 +1,30 @@
 import logging
-import numpy as np
-from scipy.stats import multivariate_normal
 from typing import Iterable
 
+import numpy as np
+from scipy.stats import multivariate_normal
+
 from ..problem import Problem
-from ..result import Result
-from .result import ProfilerResult
+from ..result import ProfilerResult, Result
 from .util import initialize_profile
 
 logger = logging.getLogger(__name__)
 
 
 def approximate_parameter_profile(
-        problem: Problem,
-        result: Result,
-        profile_index: Iterable[int] = None,
-        profile_list: int = None,
-        result_index: int = 0,
-        n_steps: int = 100,
+    problem: Problem,
+    result: Result,
+    profile_index: Iterable[int] = None,
+    profile_list: int = None,
+    result_index: int = 0,
+    n_steps: int = 100,
 ) -> Result:
     """
-    Calculate profiles based on an approximation via a normal likelihood
-    centered at the chosen optimal parameter value, with the covariance matrix
-    being the Hessian or FIM.
+    Calculate profile approximation.
+
+    Based on an approximation via a normal likelihood centered at the chosen
+    optimal parameter value, with the covariance matrix being the Hessian or
+    FIM.
 
     Parameters
     ----------
@@ -58,8 +60,9 @@ def approximate_parameter_profile(
 
     # create the profile result object (retrieve global optimum) or append to
     # existing list of profiles
-    global_opt = initialize_profile(problem, result, result_index,
-                                    profile_index, profile_list)
+    global_opt = initialize_profile(
+        problem, result, result_index, profile_index, profile_list
+    )
 
     # extract optimization result
     optimizer_result = result.optimize_result.list[result_index]
@@ -75,7 +78,8 @@ def approximate_parameter_profile(
     if hess is None or np.isnan(hess).any():
         logger.info("Computing Hessian/FIM as not available in result.")
         hess = problem.objective(
-            problem.get_reduced_vector(x), sensi_orders=(2,))
+            problem.get_reduced_vector(x), sensi_orders=(2,)
+        )
 
     # inverse of the hessian
     sigma = np.linalg.inv(hess)
@@ -91,20 +95,23 @@ def approximate_parameter_profile(
 
         i_free_par = problem.full_index_to_free_index(i_par)
 
-        ys = multivariate_normal.pdf(xs[i_par], mean=x[i_par],
-                                     cov=sigma[i_free_par, i_free_par])
+        ys = multivariate_normal.pdf(
+            xs[i_par], mean=x[i_par], cov=sigma[i_free_par, i_free_par]
+        )
 
-        fvals = - np.log(ys)
+        fvals = -np.log(ys)
         ratios = ys / ys.max() * ratio_scaling
 
         profiler_result = ProfilerResult(
             x_path=xs,
             fval_path=fvals,
-            ratio_path=ratios
+            ratio_path=ratios,
         )
 
         result.profile_result.set_profiler_result(
             profiler_result=profiler_result,
-            i_par=i_par, profile_list=profile_list)
+            i_par=i_par,
+            profile_list=profile_list,
+        )
 
     return result
