@@ -24,11 +24,17 @@ class Result:
         The results of the sampler run.
     """
 
-    def __init__(self, problem=None):
+    def __init__(
+        self,
+        problem=None,
+        optimize_result: OptimizeResult = None,
+        profile_result: ProfileResult = None,
+        sample_result: SampleResult = None,
+    ):
         self.problem = problem
-        self.optimize_result = OptimizeResult()
-        self.profile_result = ProfileResult()
-        self.sample_result = SampleResult()
+        self.optimize_result = optimize_result or OptimizeResult()
+        self.profile_result = profile_result or ProfileResult()
+        self.sample_result = sample_result or SampleResult()
 
     def summary(self) -> str:
         """Get summary of the object."""
